==> openx-2.6.5.tar.bz2: openx-2.6.5/lib/max/language/bg/userlog.lang.php <==
<?php

  /*
+---------------------------------------------------------------------------+
| OpenX v2.6                                             |
| ==========                            |
|                                                                           |
| Copyright (c) 2003-2009 OpenX Limited                                     |
| For contact details, see: http://www.openx.org/                           |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: userlog.lang.php 33112 2009-03-02 12:07:14Z andrew.hill $
  */


// Note: New translations not found in original lang files but found in CSV
$GLOBALS['strMaintenance'] = "Поддръжка";
$GLOBALS['strDelete'] = "Изтрий";
$GLOBALS['strZone'] = "Никоя";
$GLOBALS['strDeleted'] = "Изтрий";
$GLOBALS['strPreference'] = "Предпочитания";
?>

==> openx-2.8.5.tar.bz2: openx-2.8.5/lib/max/language/bg/userlog.lang.php <==
<?php

/*
+---------------------------------------------------------------------------+
| OpenX v2.8                                                                |
| ==========                                                                |
|                                                                           |
| Copyright (c) 2003-2009 OpenX Limited                                     |
| For contact details, see: http://www.openx.org/                           |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: translation.php 28570 2008-11-06 16:21:37Z chris.nutting $
*/



// Note: New translations not found in original lang files but found in CSV
$GLOBALS['strMaintenance'] = "Поддръжка";
$GLOBALS['strDelete'] = "Изтриване";
$GLOBALS['strAction'] = "Действие";
$GLOBALS['strAdvertiser'] = "Рекламодател";
$GLOBALS['strCampaign'] = "Кампания";
$GLOBALS['strPublisher'] = "Уебсайт";
$GLOBALS['strZone'] = "Зона";
$GLOBALS['strDeleted'] = "Изтрий";
?>
